FLAC - documentation
Author: Josh Coalson
Description: A free, open source codec for lossless audio compression and decompression
Keywords: free,lossless,audio,codec,encoder,decoder,compression,compressor,archival,archive,archiving,backup,music

known bugs
The following are major known bugs in the current (1.3.2) release:

- When encoding to Ogg FLAC, the number of seek points is limited to 240.

reporting bugs
To report a bug, please go to the FLAC bug tracker (or appropriately the feature request tracker, patch page, or support page).
First check that there is not already an existing request. If you do submit a new request, make sure and provide an email contact and use the Monitor feature.

Copyright (c) 2000-2009 Josh Coalson Copyright (c) 2011-2016 Xiph.Org Foundation |